# ConfigurationLoader
#
# Loads all configuration files from the 'application/config' directory
# if it exists. Otherwise, doesn't do anything.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/

require 'yaml'

require_relative './loader'

class ConfigurationLoader < Loader
	def initialize(client)
		super(client)
		@type = 'config'
		get_all
	end

	def get(config_file)
		if config_folder_exists and config_file_exists config_file then
			@client.config[config_file] = YAML.load File.read "./app/config/#{config_file}.yml"
		end
	end

	def get_all
		if config_folder_exists
			config_folder = Dir.new './app/config/'

			config_folder.each do |file|
				if file != '.' and file != '..'
					file['.yml'] = ''
					get file
				end
			end
		end
	end

	private

	def config_folder_exists
		Dir.exists? './app/config'
	end

	def config_file_exists(file)
		File.exists? "./app/config/#{file}.yml"
	end
end